spelling stuff

Andreas Mohr andi at rhlx01.fht-esslingen.de
Sun Feb 24 08:04:04 CST 2002


Hi all,

just a huge bunch of spelling/alignment fixes.

-- 
Andreas Mohr                        Stauferstr. 6, D-71272 Renningen, Germany
-------------- next part --------------
Determining best CVS host...
Using CVSROOT :pserver:cvs at rhlx01.fht-esslingen.de:/home/wine
Index: dlls/comctl32/rebar.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/rebar.c,v
retrieving revision 1.55
diff -u -r1.55 rebar.c
--- dlls/comctl32/rebar.c	12 Feb 2002 18:43:24 -0000	1.55
+++ dlls/comctl32/rebar.c	24 Feb 2002 11:56:48 -0000
@@ -3751,7 +3751,7 @@
     REBAR_BAND *band1, *band2;
     POINTS ptsmove;
 
-    /* Validate entry as hit on Gripper has occured */
+    /* Validate entry as hit on Gripper has occurred */
     if (GetCapture() != infoPtr->hwndSelf) return 0;
     if (infoPtr->ihitBand == -1) return 0;
 
Index: dlls/comctl32/updown.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/updown.c,v
retrieving revision 1.34
diff -u -r1.34 updown.c
--- dlls/comctl32/updown.c	5 Feb 2002 18:08:01 -0000	1.34
+++ dlls/comctl32/updown.c	24 Feb 2002 11:57:07 -0000
@@ -219,7 +219,7 @@
  * it stores it in the control's CurVal
  * returns:
  *   TRUE  - if it read the integer from the buddy successfully
- *   FALSE - if an error occured
+ *   FALSE - if an error occurred
  */
 static BOOL UPDOWN_GetBuddyInt (UPDOWN_INFO *infoPtr)
 {
@@ -265,7 +265,7 @@
  * Tries to set the pos to the buddy window based on current pos
  * returns:
  *   TRUE  - if it set the caption of the  buddy successfully
- *   FALSE - if an error occured
+ *   FALSE - if an error occurred
  */
 static BOOL UPDOWN_SetBuddyInt (UPDOWN_INFO *infoPtr)
 {
Index: dlls/kernel/console.c
===================================================================
RCS file: /home/wine/wine/dlls/kernel/console.c,v
retrieving revision 1.2
diff -u -r1.2 console.c
--- dlls/kernel/console.c	4 Dec 2001 19:40:54 -0000	1.2
+++ dlls/kernel/console.c	24 Feb 2002 11:57:10 -0000
@@ -36,7 +36,7 @@
 static UINT console_input_codepage;
 static UINT console_output_codepage;
 
-/* map input records to Ascii */
+/* map input records to ASCII */
 static void input_records_WtoA( INPUT_RECORD *buffer, int count )
 {
     int i;
@@ -66,7 +66,7 @@
     }
 }
 
-/* map char infos to Ascii */
+/* map char infos to ASCII */
 static void char_info_WtoA( CHAR_INFO *buffer, int count )
 {
     char ch;
Index: dlls/quartz/audren.c
===================================================================
RCS file: /home/wine/wine/dlls/quartz/audren.c,v
retrieving revision 1.6
diff -u -r1.6 audren.c
--- dlls/quartz/audren.c	19 Feb 2002 18:30:29 -0000	1.6
+++ dlls/quartz/audren.c	24 Feb 2002 11:57:11 -0000
@@ -2,8 +2,8 @@
  * Audio Renderer (CLSID_AudioRender)
  *
  * FIXME
- *  - implements IRefereneceClock.
- *  - implements seeking.
+ *  - implement IReferenceClock.
+ *  - implement seeking.
  *
  * hidenori at a2.ctktv.ne.jp
  */
Index: dlls/richedit/charlist.c
===================================================================
RCS file: /home/wine/wine/dlls/richedit/charlist.c,v
retrieving revision 1.3
diff -u -r1.3 charlist.c
--- dlls/richedit/charlist.c	14 Jan 2002 19:44:07 -0000	1.3
+++ dlls/richedit/charlist.c	24 Feb 2002 11:57:11 -0000
@@ -106,7 +106,7 @@
         CHARLIST_Dequeue(pCharList);       
 }
 
-/* this function count the number of occurences of a caracter */
+/* this function counts the number of occurrences of a caracter */
 int CHARLIST_CountChar(CHARLIST* pCharList, char myChar)
 {
     CHARLISTENTRY *pCurrent;
Index: dlls/shell32/pidl.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/pidl.c,v
retrieving revision 1.66
diff -u -r1.66 pidl.c
--- dlls/shell32/pidl.c	31 Jan 2002 21:05:05 -0000	1.66
+++ dlls/shell32/pidl.c	24 Feb 2002 11:57:16 -0000
@@ -171,7 +171,7 @@
  * ILClone [SHELL32.18]
  *
  * NOTES
- *    dupicate an idlist
+ *    duplicate an idlist
  */
 LPITEMIDLIST WINAPI ILClone (LPCITEMIDLIST pidl)
 { DWORD    len;
Index: dlls/winedos/devices.c
===================================================================
RCS file: /home/wine/wine/dlls/winedos/devices.c,v
retrieving revision 1.1
diff -u -r1.1 devices.c
--- dlls/winedos/devices.c	4 Dec 2001 19:54:45 -0000	1.1
+++ dlls/winedos/devices.c	24 Feb 2002 11:57:17 -0000
@@ -235,7 +235,7 @@
 	  /* line buffer emptied */
 	  lol->offs_unread_CON = 0;
 	  curbuffer = NULL;
-	  /* if we're not in raw mode, call it a day*/
+	  /* if we're not in raw mode, call it a day */
 	  if (!(con->attr & ATTR_RAW)) {
 	    hdr->status = STAT_DONE;
 	    io->count = len;
Index: dlls/winspool/info.c
===================================================================
RCS file: /home/wine/wine/dlls/winspool/info.c,v
retrieving revision 1.48
diff -u -r1.48 info.c
--- dlls/winspool/info.c	2 Feb 2002 18:42:18 -0000	1.48
+++ dlls/winspool/info.c	24 Feb 2002 11:57:23 -0000
@@ -188,7 +188,7 @@
     }
     /* 3. Check if we have an input filter program. If we have one, it 
      *    most likely is one capable of converting postscript.
-     *    (Could probably check for occurence of 'gs' or 'ghostscript' 
+     *    (Could probably check for occurrence of 'gs' or 'ghostscript' 
      *     in the if file itself.)
      */
     if (strstr(pent,":if=/")) {
Index: graphics/painting.c
===================================================================
RCS file: /home/wine/wine/graphics/painting.c,v
retrieving revision 1.45
diff -u -r1.45 painting.c
--- graphics/painting.c	11 Sep 2001 00:32:33 -0000	1.45
+++ graphics/painting.c	24 Feb 2002 11:57:27 -0000
@@ -167,7 +167,7 @@
      */
     result = Arc(hdc, left, top, right, bottom, xstart, ystart, xend, yend);
     /*
-     * If no error occured, the current position is moved to the ending
+     * If no error occurred, the current position is moved to the ending
      * point of the arc.
      */
     if (result) MoveToEx(hdc, xend, yend, NULL);
Index: graphics/x11drv/dib.c
===================================================================
RCS file: /home/wine/wine/graphics/x11drv/dib.c,v
retrieving revision 1.86
diff -u -r1.86 dib.c
--- graphics/x11drv/dib.c	29 Jan 2002 17:50:26 -0000	1.86
+++ graphics/x11drv/dib.c	24 Feb 2002 11:57:34 -0000
@@ -5597,7 +5597,7 @@
                         wine_tsx11_unlock();
                         return image; /* Success! */
                     }
-                    /* An error occured */
+                    /* An error occurred */
                     XShmErrorFlag = 0;
                     XSetErrorHandler(WineXHandler);
                 }
Index: msdos/vxd.c
===================================================================
RCS file: /home/wine/wine/msdos/vxd.c,v
retrieving revision 1.31
diff -u -r1.31 vxd.c
--- msdos/vxd.c	23 Nov 2001 18:44:47 -0000	1.31
+++ msdos/vxd.c	24 Feb 2002 11:57:38 -0000
@@ -583,7 +583,7 @@
          * We search between the addresses of the exported symbols SetFS
          * and StackLinearToSegmented for the byte sequence '0F 01 04'
          * (this is the opcode of 'sgdt [si]'). We then search backwards
-         * from this address for the last occurrance of 'CB' (retf) that marks
+         * from this address for the last occurrence of 'CB' (retf) that marks
          * the end of the preceeding function. The following byte (which
          * should now be the first byte of the function we are looking for)
          * will be replaced by 'CB' (retf).
Index: programs/avitools/aviinfo.c
===================================================================
RCS file: /home/wine/wine/programs/avitools/aviinfo.c,v
retrieving revision 1.6
diff -u -r1.6 aviinfo.c
--- programs/avitools/aviinfo.c	2 Feb 2002 18:42:20 -0000	1.6
+++ programs/avitools/aviinfo.c	24 Feb 2002 11:57:39 -0000
@@ -32,7 +32,7 @@
 #else
 # define XXT(x) fn##x = (void*)GetProcAddress(avifil32,#x##"A");assert(fn##x);
 #endif
-	/* Non character dependend routines: */
+	/* Non character dependent routines: */
 	XX (AVIFileInit);
 	XX (AVIFileExit);
 	XX (AVIFileRelease);
Index: tools/winedump/misc.c
===================================================================
RCS file: /home/wine/wine/tools/winedump/misc.c,v
retrieving revision 1.1
diff -u -r1.1 misc.c
--- tools/winedump/misc.c	7 Sep 2001 16:04:39 -0000	1.1
+++ tools/winedump/misc.c	24 Feb 2002 11:57:39 -0000
@@ -136,7 +136,7 @@
 /*******************************************************************
  *         str_find_set
  *
- * Locate the first occurence of a set of characters in a string
+ * Locate the first occurrence of a set of characters in a string
  */
 const char *str_find_set (const char *str, const char *findset)
 {
Index: tools/wrc/dumpres.c
===================================================================
RCS file: /home/wine/wine/tools/wrc/dumpres.c,v
retrieving revision 1.11
diff -u -r1.11 dumpres.c
--- tools/wrc/dumpres.c	11 Nov 2000 00:38:37 -0000	1.11
+++ tools/wrc/dumpres.c	24 Feb 2002 11:57:39 -0000
@@ -62,7 +62,7 @@
  *	maxlen	- Max chars to copy
  * Output	: 'cs'
  * Description	: Copy a unicode string to ascii. Copying stops after the
- *		  first occuring '\0' or when maxlen-1 chars are copied. The
+ *		  first occurring '\0' or when maxlen-1 chars are copied. The
  *		  String is always nul terminated.
  * Remarks	: No codepage translation is done.
  *****************************************************************************


More information about the wine-patches mailing list
Index: dlls/comctl32/treeview.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/treeview.c,v
retrieving revision 1.97
diff -u -r1.97 treeview.c
--- dlls/comctl32/treeview.c	4 Feb 2002 18:37:32 -0000	1.97
+++ dlls/comctl32/treeview.c	24 Feb 2002 11:57:05 -0000
@@ -51,8 +51,8 @@
   LPARAM    lParam;
   int       iIntegral;      /* item height multiplier (1 is normal) */
   int       iLevel;         /* indentation level:0=root level */
-  HTREEITEM parent;         /* handle to parent or 0 if at root*/
-  HTREEITEM firstChild;     /* handle to first child or 0 if no child*/
+  HTREEITEM parent;         /* handle to parent or 0 if at root */
+  HTREEITEM firstChild;     /* handle to first child or 0 if no child */
   HTREEITEM lastChild;
   HTREEITEM prevSibling;    /* handle to prev item in list, 0 if first */
   HTREEITEM nextSibling;    /* handle to next item in list, 0 if last */
@@ -136,7 +136,7 @@
 #define TV_HSCROLL 	0x01    /* treeview too large to fit in window */
 #define TV_VSCROLL 	0x02	/* (horizontal/vertical) */
 #define TV_LDRAG		0x04	/* Lbutton pushed to start drag */
-#define TV_LDRAGGING	0x08	/* Lbutton pushed, mouse moved.  */
+#define TV_LDRAGGING	0x08	/* Lbutton pushed, mouse moved. */
 #define TV_RDRAG		0x10	/* dito Rbutton */
 #define TV_RDRAGGING	0x20	
 
@@ -2306,7 +2306,7 @@
 
 	if ((wineItem->state & TVIS_SELECTED) && (wineItem->iSelectedImage))
 	{
-	    /* The item is curently selected */
+	    /* The item is currently selected */
 	    imageIndex = wineItem->iSelectedImage;
 	}
 	else
@@ -3720,7 +3720,7 @@
 	goto setfocus;
     }
     else if (bTrack)
-    {   /* if TREEVIEW_TrackMouse == 1 dragging occured and the cursor left the dragged item's rectangle */
+    {   /* if TREEVIEW_TrackMouse == 1 dragging occurred and the cursor left the dragged item's rectangle */
 	if (TREEVIEW_TrackMouse(infoPtr, ht.pt))
 	{
 	    TREEVIEW_SendTreeviewDnDNotify(infoPtr, TVN_BEGINDRAGA, ht.hItem,
@@ -3748,7 +3748,7 @@
 
     /* 
      * If the style allows editing and the node is already selected 
      * and the click occured on the item label...
      */
     if ((infoPtr->dwStyle & TVS_EDITLABELS) &&
 	        (ht.flags & TVHT_ONITEMLABEL) && (infoPtr->selectedItem == ht.hItem))
@@ -4665,7 +4665,7 @@
 
     /* tool tip is automatically destroyed: we are its owner */
 
-    /* Restore original windproc. */
+    /* Restore original wndproc */
     if (infoPtr->hwndEdit)
 	SetWindowLongA(infoPtr->hwndEdit, GWL_WNDPROC,
 		       (LONG)infoPtr->wpEditOrig);
@@ -3748,7 +3748,7 @@
     /* 
      * If the style allows editing and the node is already selected 
-     * and the click occured on the item label...
+     * and the click occurred on the item label...
      */
     if ((infoPtr->dwStyle & TVS_EDITLABELS) &&